![fsociety gif](https://raw.githubusercontent.com/fsociety-team/fsociety/master/fsociety.gif)

[comment]: # "TODO: Replace with fsociety gif in the same style"

# fsociety [![PyPi](https://img.shields.io/pypi/v/fsociety?style=flat-square)](https://pypi.org/project/fsociety/) [![Python Version](https://img.shields.io/pypi/pyversions/fsociety?color=orange&style=flat-square)](https://www.python.org/download/releases/3.0/) [![License](https://img.shields.io/pypi/l/fsociety?style=flat-square)](https://github.com/fsociety-team/fsociety/blob/master/LICENSE) [![Discord](https://img.shields.io/discord/541829295870443542?style=flat-square&color=%237289da)](https://discord.gg/BaBpuPn)

A Penetration Testing Framework

## Install

```bash
pip install fsociety
```

## Usage

```bash
fsociety
```

## Develop

```bash
git clone https://github.com/fsociety-team/fsociety.git
pip install -e ".[dev]"
```

## License

[MIT Licence](LICENSE)
